==> types_boto3_full-1.35.74-py3-none-any.whl: types_boto3_controlcatalog/paginator.py <==
"""
Type annotations for controlcatalog service client paginators.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_controlcatalog/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_controlcatalog.client import ControlCatalogClient
    from types_boto3_controlcatalog.paginator import (
        ListCommonControlsPaginator,
        ListControlsPaginator,
        ListDomainsPaginator,
        ListObjectivesPaginator,
    )

    session = Session()
    client: ControlCatalogClient = session.client("controlcatalog")

    list_common_controls_paginator: ListCommonControlsPaginator = client.get_paginator("list_common_controls")
    list_controls_paginator: ListControlsPaginator = client.get_paginator("list_controls")
    list_domains_paginator: ListDomainsPaginator = client.get_paginator("list_domains")
    list_objectives_paginator: ListObjectivesPaginator = client.get_paginator("list_objectives")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListCommonControlsRequestListCommonControlsPaginateTypeDef,
    ListCommonControlsResponseTypeDef,
    ListControlsRequestListControlsPaginateTypeDef,
    ListControlsResponseTypeDef,
    ListDomainsRequestListDomainsPaginateTypeDef,
    ListDomainsResponseTypeDef,
    ListObjectivesRequestListObjectivesPaginateTypeDef,
    ListObjectivesResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "ListCommonControlsPaginator",
    "ListControlsPaginator",
    "ListDomainsPaginator",
    "ListObjectivesPaginator",
)


_ItemTypeDef = TypeVar("_ItemTypeDef")


class _PageIterator(PageIterator, Generic[_ItemTypeDef]):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """


class ListCommonControlsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/controlcatalog/paginator/ListCommonControls.html#ControlCatalog.Paginator.ListCommonControls)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_controlcatalog/paginators/#listcommoncontrolspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListCommonControlsRequestListCommonControlsPaginateTypeDef]
    ) -> _PageIterator[ListCommonControlsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/controlcatalog/paginator/ListCommonControls.html#ControlCatalog.Paginator.ListCommonControls.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_controlcatalog/paginators/#listcommoncontrolspaginator)
        """


class ListControlsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/controlcatalog/paginator/ListControls.html#ControlCatalog.Paginator.ListControls)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_controlcatalog/paginators/#listcontrolspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListControlsRequestListControlsPaginateTypeDef]
    ) -> _PageIterator[ListControlsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/controlcatalog/paginator/ListControls.html#ControlCatalog.Paginator.ListControls.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_controlcatalog/paginators/#listcontrolspaginator)
        """


class ListDomainsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/controlcatalog/paginator/ListDomains.html#ControlCatalog.Paginator.ListDomains)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_controlcatalog/paginators/#listdomainspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListDomainsRequestListDomainsPaginateTypeDef]
    ) -> _PageIterator[ListDomainsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/controlcatalog/paginator/ListDomains.html#ControlCatalog.Paginator.ListDomains.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_controlcatalog/paginators/#listdomainspaginator)
        """


class ListObjectivesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/controlcatalog/paginator/ListObjectives.html#ControlCatalog.Paginator.ListObjectives)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_controlcatalog/paginators/#listobjectivespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListObjectivesRequestListObjectivesPaginateTypeDef]
    ) -> _PageIterator[ListObjectivesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/controlcatalog/paginator/ListObjectives.html#ControlCatalog.Paginator.ListObjectives.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_controlcatalog/paginators/#listobjectivespaginator)
        """

==> types_boto3_full-1.35.91-py3-none-any.whl: types_boto3_controlcatalog/paginator.py <==
"""
Type annotations for controlcatalog service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_controlcatalog/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_controlcatalog.client import ControlCatalogClient
    from types_boto3_controlcatalog.paginator import (
        ListCommonControlsPaginator,
        ListControlsPaginator,
        ListDomainsPaginator,
        ListObjectivesPaginator,
    )

    session = Session()
    client: ControlCatalogClient = session.client("controlcatalog")

    list_common_controls_paginator: ListCommonControlsPaginator = client.get_paginator("list_common_controls")
    list_controls_paginator: ListControlsPaginator = client.get_paginator("list_controls")
    list_domains_paginator: ListDomainsPaginator = client.get_paginator("list_domains")
    list_objectives_paginator: ListObjectivesPaginator = client.get_paginator("list_objectives")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListCommonControlsRequestPaginateTypeDef,
    ListCommonControlsResponseTypeDef,
    ListControlsRequestPaginateTypeDef,
    ListControlsResponseTypeDef,
    ListDomainsRequestPaginateTypeDef,
    ListDomainsResponseTypeDef,
    ListObjectivesRequestPaginateTypeDef,
    ListObjectivesResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "ListCommonControlsPaginator",
    "ListControlsPaginator",
    "ListDomainsPaginator",
    "ListObjectivesPaginator",
)


if TYPE_CHECKING:
    _ListCommonControlsPaginatorBase = Paginator[ListCommonControlsResponseTypeDef]
else:
    _ListCommonControlsPaginatorBase = Paginator  # type: ignore[assignment]


class ListCommonControlsPaginator(_ListCommonControlsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/controlcatalog/paginator/ListCommonControls.html#ControlCatalog.Paginator.ListCommonControls)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_controlcatalog/paginators/#listcommoncontrolspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListCommonControlsRequestPaginateTypeDef]
    ) -> PageIterator[ListCommonControlsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/controlcatalog/paginator/ListCommonControls.html#ControlCatalog.Paginator.ListCommonControls.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_controlcatalog/paginators/#listcommoncontrolspaginator)
        """


if TYPE_CHECKING:
    _ListControlsPaginatorBase = Paginator[ListControlsResponseTypeDef]
else:
    _ListControlsPaginatorBase = Paginator  # type: ignore[assignment]


class ListControlsPaginator(_ListControlsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/controlcatalog/paginator/ListControls.html#ControlCatalog.Paginator.ListControls)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_controlcatalog/paginators/#listcontrolspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListControlsRequestPaginateTypeDef]
    ) -> PageIterator[ListControlsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/controlcatalog/paginator/ListControls.html#ControlCatalog.Paginator.ListControls.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_controlcatalog/paginators/#listcontrolspaginator)
        """


if TYPE_CHECKING:
    _ListDomainsPaginatorBase = Paginator[ListDomainsResponseTypeDef]
else:
    _ListDomainsPaginatorBase = Paginator  # type: ignore[assignment]


class ListDomainsPaginator(_ListDomainsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/controlcatalog/paginator/ListDomains.html#ControlCatalog.Paginator.ListDomains)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_controlcatalog/paginators/#listdomainspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListDomainsRequestPaginateTypeDef]
    ) -> PageIterator[ListDomainsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/controlcatalog/paginator/ListDomains.html#ControlCatalog.Paginator.ListDomains.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_controlcatalog/paginators/#listdomainspaginator)
        """


if TYPE_CHECKING:
    _ListObjectivesPaginatorBase = Paginator[ListObjectivesResponseTypeDef]
else:
    _ListObjectivesPaginatorBase = Paginator  # type: ignore[assignment]


class ListObjectivesPaginator(_ListObjectivesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/controlcatalog/paginator/ListObjectives.html#ControlCatalog.Paginator.ListObjectives)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_controlcatalog/paginators/#listobjectivespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListObjectivesRequestPaginateTypeDef]
    ) -> PageIterator[ListObjectivesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/controlcatalog/paginator/ListObjectives.html#ControlCatalog.Paginator.ListObjectives.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_controlcatalog/paginators/#listobjectivespaginator)
        """
